==> qt5-base-debuginfo-5.4.2-2.tar.xz: usr/src/debug/qt5-base-5.4.2-2/examples/opengl/cube/.rcc/qrc_shaders.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.4.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.4.2-2.x86_64/src/qtbase-opensource-src-5.4.2/examples/opengl/cube/vshader.glsl
  0x0,0x0,0x1,0xf1,
  0x23,
  0x69,0x66,0x64,0x65,0x66,0x20,0x47,0x4c,0x5f,0x45,0x53,0xa,0x2f,0x2f,0x20,0x53,
  0x65,0x74,0x20,0x64,0x65,0x66,0x61,0x75,0x6c,0x74,0x20,0x70,0x72,0x65,0x63,0x69,
  0x73,0x69,0x6f,0x6e,0x20,0x74,0x6f,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0xa,0x70,
  0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,
  0x20,0x69,0x6e,0x74,0x3b,0xa,0x70,0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,
  0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,0x20,0x66,0x6c,0x6f,0x61,0x74,0x3b,0xa,0x23,
  0x65,0x6e,0x64,0x69,0x66,0xa,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x6d,
  0x61,0x74,0x34,0x20,0x6d,0x76,0x70,0x5f,0x6d,0x61,0x74,0x72,0x69,0x78,0x3b,0xa,
  0xa,0x61,0x74,0x74,0x72,0x69,0x62,0x75,0x74,0x65,0x20,0x76,0x65,0x63,0x34,0x20,
  0x61,0x5f,0x70,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x3b,0xa,0x61,0x74,0x74,0x72,
  0x69,0x62,0x75,0x74,0x65,0x20,0x76,0x65,0x63,0x32,0x20,0x61,0x5f,0x74,0x65,0x78,
  0x63,0x6f,0x6f,0x72,0x64,0x3b,0xa,0xa,0x76,0x61,0x72,0x79,0x69,0x6e,0x67,0x20,
  0x76,0x65,0x63,0x32,0x20,0x76,0x5f,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x3b,
  0xa,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,
  0x61,0x69,0x6e,0x28,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x43,
  0x61,0x6c,0x63,0x75,0x6c,0x61,0x74,0x65,0x20,0x76,0x65,0x72,0x74,0x65,0x78,0x20,
  0x70,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x20,0x69,0x6e,0x20,0x73,0x63,0x72,0x65,
  0x65,0x6e,0x20,0x73,0x70,0x61,0x63,0x65,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,0x5f,
  0x50,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x20,0x3d,0x20,0x6d,0x76,0x70,0x5f,0x6d,
  0x61,0x74,0x72,0x69,0x78,0x20,0x2a,0x20,0x61,0x5f,0x70,0x6f,0x73,0x69,0x74,0x69,
  0x6f,0x6e,0x3b,0xa,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x50,0x61,0x73,0x73,
  0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x20,0x63,0x6f,0x6f,0x72,0x64,0x69,0x6e,
  0x61,0x74,0x65,0x20,0x74,0x6f,0x20,0x66,0x72,0x61,0x67,0x6d,0x65,0x6e,0x74,0x20,
  0x73,0x68,0x61,0x64,0x65,0x72,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x56,0x61,
  0x6c,0x75,0x65,0x20,0x77,0x69,0x6c,0x6c,0x20,0x62,0x65,0x20,0x61,0x75,0x74,0x6f,
  0x6d,0x61,0x74,0x69,0x63,0x61,0x6c,0x6c,0x79,0x20,0x69,0x6e,0x74,0x65,0x72,0x70,
  0x6f,0x6c,0x61,0x74,0x65,0x64,0x20,0x74,0x6f,0x20,0x66,0x72,0x61,0x67,0x6d,0x65,
  0x6e,0x74,0x73,0x20,0x69,0x6e,0x73,0x69,0x64,0x65,0x20,0x70,0x6f,0x6c,0x79,0x67,
  0x6f,0x6e,0x20,0x66,0x61,0x63,0x65,0x73,0xa,0x20,0x20,0x20,0x20,0x76,0x5f,0x74,
  0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x20,0x3d,0x20,0x61,0x5f,0x74,0x65,0x78,0x63,
  0x6f,0x6f,0x72,0x64,0x3b,0xa,0x7d,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,
  
    // /usr/src/ports/qt5-base/qt5-base-5.4.2-2.x86_64/src/qtbase-opensource-src-5.4.2/examples/opengl/cube/fshader.glsl
  0x0,0x0,0x1,0x19,
  0x23,
  0x69,0x66,0x64,0x65,0x66,0x20,0x47,0x4c,0x5f,0x45,0x53,0xa,0x2f,0x2f,0x20,0x53,
  0x65,0x74,0x20,0x64,0x65,0x66,0x61,0x75,0x6c,0x74,0x20,0x70,0x72,0x65,0x63,0x69,
  0x73,0x69,0x6f,0x6e,0x20,0x74,0x6f,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0xa,0x70,
  0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,
  0x20,0x69,0x6e,0x74,0x3b,0xa,0x70,0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,
  0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,0x20,0x66,0x6c,0x6f,0x61,0x74,0x3b,0xa,0x23,
  0x65,0x6e,0x64,0x69,0x66,0xa,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x73,
  0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,
  0x3b,0xa,0xa,0x76,0x61,0x72,0x79,0x69,0x6e,0x67,0x20,0x76,0x65,0x63,0x32,0x20,
  0x76,0x5f,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x3b,0xa,0xa,0x2f,0x2f,0x21,
  0x20,0x5b,0x30,0x5d,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x29,
  0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x53,0x65,0x74,0x20,0x66,0x72,
  0x61,0x67,0x6d,0x65,0x6e,0x74,0x20,0x63,0x6f,0x6c,0x6f,0x72,0x20,0x66,0x72,0x6f,
  0x6d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,
  0x5f,0x46,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,0x3d,0x20,0x74,0x65,0x78,
  0x74,0x75,0x72,0x65,0x32,0x44,0x28,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x2c,0x20,
  0x76,0x5f,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x29,0x3b,0xa,0x7d,0xa,0x2f,
  0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // vshader.glsl
  0x0,0xc,
  0x3,0xe7,0x2c,0xdc,
  0x0,0x76,
  0x0,0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x67,0x0,0x6c,0x0,0x73,0x0,0x6c,
    // fshader.glsl
  0x0,0xc,
  0x1,0xe7,0x2c,0xdc,
  0x0,0x66,
  0x0,0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x67,0x0,0x6c,0x0,0x73,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
  // :/fshader.glsl
  0x0,0x0,0x0,0x1e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xf5,
  // :/vshader.glsl
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_shaders)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_shaders)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_shaders)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_shaders)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_shaders)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_shaders)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.5.1-1.tar.xz: usr/src/debug/qt5-base-5.5.1-1/examples/opengl/cube/.rcc/qrc_shaders.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.5.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.5.1-1.i686/src/qtbase-opensource-src-5.5.1/examples/opengl/cube/vshader.glsl
  0x0,0x0,0x1,0xf1,
  0x23,
  0x69,0x66,0x64,0x65,0x66,0x20,0x47,0x4c,0x5f,0x45,0x53,0xa,0x2f,0x2f,0x20,0x53,
  0x65,0x74,0x20,0x64,0x65,0x66,0x61,0x75,0x6c,0x74,0x20,0x70,0x72,0x65,0x63,0x69,
  0x73,0x69,0x6f,0x6e,0x20,0x74,0x6f,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0xa,0x70,
  0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,
  0x20,0x69,0x6e,0x74,0x3b,0xa,0x70,0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,
  0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,0x20,0x66,0x6c,0x6f,0x61,0x74,0x3b,0xa,0x23,
  0x65,0x6e,0x64,0x69,0x66,0xa,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x6d,
  0x61,0x74,0x34,0x20,0x6d,0x76,0x70,0x5f,0x6d,0x61,0x74,0x72,0x69,0x78,0x3b,0xa,
  0xa,0x61,0x74,0x74,0x72,0x69,0x62,0x75,0x74,0x65,0x20,0x76,0x65,0x63,0x34,0x20,
  0x61,0x5f,0x70,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x3b,0xa,0x61,0x74,0x74,0x72,
  0x69,0x62,0x75,0x74,0x65,0x20,0x76,0x65,0x63,0x32,0x20,0x61,0x5f,0x74,0x65,0x78,
  0x63,0x6f,0x6f,0x72,0x64,0x3b,0xa,0xa,0x76,0x61,0x72,0x79,0x69,0x6e,0x67,0x20,
  0x76,0x65,0x63,0x32,0x20,0x76,0x5f,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x3b,
  0xa,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,
  0x61,0x69,0x6e,0x28,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x43,
  0x61,0x6c,0x63,0x75,0x6c,0x61,0x74,0x65,0x20,0x76,0x65,0x72,0x74,0x65,0x78,0x20,
  0x70,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x20,0x69,0x6e,0x20,0x73,0x63,0x72,0x65,
  0x65,0x6e,0x20,0x73,0x70,0x61,0x63,0x65,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,0x5f,
  0x50,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x20,0x3d,0x20,0x6d,0x76,0x70,0x5f,0x6d,
  0x61,0x74,0x72,0x69,0x78,0x20,0x2a,0x20,0x61,0x5f,0x70,0x6f,0x73,0x69,0x74,0x69,
  0x6f,0x6e,0x3b,0xa,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x50,0x61,0x73,0x73,
  0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x20,0x63,0x6f,0x6f,0x72,0x64,0x69,0x6e,
  0x61,0x74,0x65,0x20,0x74,0x6f,0x20,0x66,0x72,0x61,0x67,0x6d,0x65,0x6e,0x74,0x20,
  0x73,0x68,0x61,0x64,0x65,0x72,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x56,0x61,
  0x6c,0x75,0x65,0x20,0x77,0x69,0x6c,0x6c,0x20,0x62,0x65,0x20,0x61,0x75,0x74,0x6f,
  0x6d,0x61,0x74,0x69,0x63,0x61,0x6c,0x6c,0x79,0x20,0x69,0x6e,0x74,0x65,0x72,0x70,
  0x6f,0x6c,0x61,0x74,0x65,0x64,0x20,0x74,0x6f,0x20,0x66,0x72,0x61,0x67,0x6d,0x65,
  0x6e,0x74,0x73,0x20,0x69,0x6e,0x73,0x69,0x64,0x65,0x20,0x70,0x6f,0x6c,0x79,0x67,
  0x6f,0x6e,0x20,0x66,0x61,0x63,0x65,0x73,0xa,0x20,0x20,0x20,0x20,0x76,0x5f,0x74,
  0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x20,0x3d,0x20,0x61,0x5f,0x74,0x65,0x78,0x63,
  0x6f,0x6f,0x72,0x64,0x3b,0xa,0x7d,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,
  
    // /usr/src/ports/qt5-base/qt5-base-5.5.1-1.i686/src/qtbase-opensource-src-5.5.1/examples/opengl/cube/fshader.glsl
  0x0,0x0,0x1,0x19,
  0x23,
  0x69,0x66,0x64,0x65,0x66,0x20,0x47,0x4c,0x5f,0x45,0x53,0xa,0x2f,0x2f,0x20,0x53,
  0x65,0x74,0x20,0x64,0x65,0x66,0x61,0x75,0x6c,0x74,0x20,0x70,0x72,0x65,0x63,0x69,
  0x73,0x69,0x6f,0x6e,0x20,0x74,0x6f,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0xa,0x70,
  0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,
  0x20,0x69,0x6e,0x74,0x3b,0xa,0x70,0x72,0x65,0x63,0x69,0x73,0x69,0x6f,0x6e,0x20,
  0x6d,0x65,0x64,0x69,0x75,0x6d,0x70,0x20,0x66,0x6c,0x6f,0x61,0x74,0x3b,0xa,0x23,
  0x65,0x6e,0x64,0x69,0x66,0xa,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x73,
  0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,
  0x3b,0xa,0xa,0x76,0x61,0x72,0x79,0x69,0x6e,0x67,0x20,0x76,0x65,0x63,0x32,0x20,
  0x76,0x5f,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x3b,0xa,0xa,0x2f,0x2f,0x21,
  0x20,0x5b,0x30,0x5d,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x29,
  0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x2f,0x2f,0x20,0x53,0x65,0x74,0x20,0x66,0x72,
  0x61,0x67,0x6d,0x65,0x6e,0x74,0x20,0x63,0x6f,0x6c,0x6f,0x72,0x20,0x66,0x72,0x6f,
  0x6d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,
  0x5f,0x46,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,0x3d,0x20,0x74,0x65,0x78,
  0x74,0x75,0x72,0x65,0x32,0x44,0x28,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x2c,0x20,
  0x76,0x5f,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x29,0x3b,0xa,0x7d,0xa,0x2f,
  0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // vshader.glsl
  0x0,0xc,
  0x3,0xe7,0x2c,0xdc,
  0x0,0x76,
  0x0,0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x67,0x0,0x6c,0x0,0x73,0x0,0x6c,
    // fshader.glsl
  0x0,0xc,
  0x1,0xe7,0x2c,0xdc,
  0x0,0x66,
  0x0,0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x67,0x0,0x6c,0x0,0x73,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
  // :/fshader.glsl
  0x0,0x0,0x0,0x1e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xf5,
  // :/vshader.glsl
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_shaders)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_shaders)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_shaders)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_shaders)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_shaders)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_shaders)(); }
   } dummy;
}
